# Changelog

## 0.0.13 (2024-08-01)

Full Changelog: [v0.0.12...v0.0.13](https://github.com/plastic-labs/honcho-python/compare/v0.0.12...v0.0.13)

### Features

* **api:** OpenAPI spec update via Stainless API ([#31](https://github.com/plastic-labs/honcho-python/issues/31)) ([f626a2c](https://github.com/plastic-labs/honcho-python/commit/f626a2c303f866dcbb65237f2570d2ed9b064351))
* **api:** update via SDK Studio ([#24](https://github.com/plastic-labs/honcho-python/issues/24)) ([e5417f8](https://github.com/plastic-labs/honcho-python/commit/e5417f859174b237fa1c912188031b786842e0d6))
* **api:** update via SDK Studio ([#30](https://github.com/plastic-labs/honcho-python/issues/30)) ([f3e9cb4](https://github.com/plastic-labs/honcho-python/commit/f3e9cb49773691962b07067c531f288942711db1))


### Chores

* fix error message import example ([#28](https://github.com/plastic-labs/honcho-python/issues/28)) ([675f719](https://github.com/plastic-labs/honcho-python/commit/675f71940a184e8a277f6db8df2604d762bae1d5))
* **internal:** add type construction helper ([#29](https://github.com/plastic-labs/honcho-python/issues/29)) ([e526f46](https://github.com/plastic-labs/honcho-python/commit/e526f463dd0dea1a9047c11cf81366a06e1ed47b))
* **internal:** codegen related update ([#26](https://github.com/plastic-labs/honcho-python/issues/26)) ([8aa9cad](https://github.com/plastic-labs/honcho-python/commit/8aa9cad685d140c45ed9c01c4d8e853434352478))
* **tests:** update prism version ([#27](https://github.com/plastic-labs/honcho-python/issues/27)) ([0aa4203](https://github.com/plastic-labs/honcho-python/commit/0aa42032400a4dcff1f11086233074e080f3097c))

## 0.0.12 (2024-05-23)

Full Changelog: [v0.0.11...v0.0.12](https://github.com/plastic-labs/honcho-python/compare/v0.0.11...v0.0.12)

### Features

* **api:** update via SDK Studio ([#22](https://github.com/plastic-labs/honcho-python/issues/22)) ([a9e7757](https://github.com/plastic-labs/honcho-python/commit/a9e7757b02f4cd560d12717af38bb85368eed581))


### Chores

* **examples:** update honcho package versions to latest ([331ce69](https://github.com/plastic-labs/honcho-python/commit/331ce69e0400690885a9cc62d92a9403e4e3953b))

## 0.0.11 (2024-05-23)

Full Changelog: [v0.0.10...v0.0.11](https://github.com/plastic-labs/honcho-python/compare/v0.0.10...v0.0.11)

### Features

* **api:** update via SDK Studio ([#19](https://github.com/plastic-labs/honcho-python/issues/19)) ([f9c3c3e](https://github.com/plastic-labs/honcho-python/commit/f9c3c3ec4934309b402f45dbeffb21e9b564dab1))


### Chores

* **internal:** version bump ([#16](https://github.com/plastic-labs/honcho-python/issues/16)) ([e873340](https://github.com/plastic-labs/honcho-python/commit/e873340f281f09c774b6cafe1502d2b7a205bcd0))

## 0.0.10 (2024-05-23)

Full Changelog: [v0.0.9...v0.0.10](https://github.com/plastic-labs/honcho-python/compare/v0.0.9...v0.0.10)

### Features

* Release 0.0.10 Demos and LangChain Integration ([#15](https://github.com/plastic-labs/honcho-python/issues/15)) ([1c6f477](https://github.com/plastic-labs/honcho-python/commit/1c6f47742494440a6b820e416aefd105e7b1a3ec))


### Chores

* **internal:** version bump ([#13](https://github.com/plastic-labs/honcho-python/issues/13)) ([05a39a1](https://github.com/plastic-labs/honcho-python/commit/05a39a1e3796f7efcc0fd143d6b72478255b88e8))

## 0.0.9 (2024-05-23)

Full Changelog: [v0.0.8...v0.0.9](https://github.com/plastic-labs/honcho-python/compare/v0.0.8...v0.0.9)

### Features

* **api:** OpenAPI spec update via Stainless API ([#12](https://github.com/plastic-labs/honcho-python/issues/12)) ([fc9f943](https://github.com/plastic-labs/honcho-python/commit/fc9f943458b81fc897d9643ff3956ed2a859a4e9))
* **api:** update via SDK Studio ([#11](https://github.com/plastic-labs/honcho-python/issues/11)) ([08b81ed](https://github.com/plastic-labs/honcho-python/commit/08b81edd9a63e10f55575ddd3d7ca542f271aed7))


### Chores

* **internal:** version bump ([#8](https://github.com/plastic-labs/honcho-python/issues/8)) ([dac6964](https://github.com/plastic-labs/honcho-python/commit/dac6964e461965e4b111a77b22a508eac849590c))

## 0.0.8 (2024-05-16)

Full Changelog: [v0.0.8-alpha.1...v0.0.8](https://github.com/plastic-labs/honcho-python/compare/v0.0.8-alpha.1...v0.0.8)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/plastic-labs/honcho-python/issues/4)) ([c8a8dbc](https://github.com/plastic-labs/honcho-python/commit/c8a8dbcf788c346ee2427762669974eb072027f0))
* **api:** update via SDK Studio ([#6](https://github.com/plastic-labs/honcho-python/issues/6)) ([5f224f6](https://github.com/plastic-labs/honcho-python/commit/5f224f611904a055860184f1d83628316ae3cf30))
* **api:** update via SDK Studio ([#7](https://github.com/plastic-labs/honcho-python/issues/7)) ([9488493](https://github.com/plastic-labs/honcho-python/commit/948849360d12d434196372b5614467ee6daf1860))

## 0.0.8-alpha.1 (2024-05-09)

Full Changelog: [v0.0.1-alpha.0...v0.0.8-alpha.1](https://github.com/plastic-labs/honcho-python/compare/v0.0.1-alpha.0...v0.0.8-alpha.1)

### Features

* **api:** OpenAPI spec update via Stainless API ([#3](https://github.com/plastic-labs/honcho-python/issues/3)) ([d2135c7](https://github.com/plastic-labs/honcho-python/commit/d2135c739d1d52b3074168d1561d85a7919663e8))
* **api:** update via SDK Studio ([c9fc257](https://github.com/plastic-labs/honcho-python/commit/c9fc2575153140bb803a0f7e674cdbcb762e9c09))
* **api:** update via SDK Studio ([c4ebb87](https://github.com/plastic-labs/honcho-python/commit/c4ebb87fc34205cc38d56a657510d83cad4b48ca))
* **api:** update via SDK Studio ([86bc8f2](https://github.com/plastic-labs/honcho-python/commit/86bc8f22ed1bed476ef578fc666533492fc3a67d))
* **api:** update via SDK Studio ([996611c](https://github.com/plastic-labs/honcho-python/commit/996611c6b9b3d9b0a6b019134bd7c31f222a356e))
* **api:** update via SDK Studio ([f1ccd91](https://github.com/plastic-labs/honcho-python/commit/f1ccd91fc4121df570b0053a1499ef2dddc9e443))
* **api:** update via SDK Studio ([4b10a42](https://github.com/plastic-labs/honcho-python/commit/4b10a422d65673f738c88aec36a556c79684dcbb))
* **api:** update via SDK Studio ([94ed61a](https://github.com/plastic-labs/honcho-python/commit/94ed61ad9140ba535c40b0551e526341b7c18901))
* **api:** update via SDK Studio ([a9df893](https://github.com/plastic-labs/honcho-python/commit/a9df8932941d6b7a1e6a2484c3e7965f1b079bb2))
* **api:** update via SDK Studio ([7d58d0b](https://github.com/plastic-labs/honcho-python/commit/7d58d0bf85b2f3c8fe9e2dcd73ca40ddf9ffd2fd))
* **api:** update via SDK Studio ([847d9c5](https://github.com/plastic-labs/honcho-python/commit/847d9c5c807a6f9f2ce981e183f5bd912fb3c6c2))
* **api:** update via SDK Studio ([45ac06b](https://github.com/plastic-labs/honcho-python/commit/45ac06b2216fc138ce3ba47eee5365eae4b96506))
* **api:** update via SDK Studio ([d1841cb](https://github.com/plastic-labs/honcho-python/commit/d1841cbf2e530d6e050df8aeeb0d1f1f06f464f0))
* **api:** update via SDK Studio ([f83704d](https://github.com/plastic-labs/honcho-python/commit/f83704dddc74d791cfdb0a26f8b17d21b1084c7c))
* **api:** update via SDK Studio ([a3b8929](https://github.com/plastic-labs/honcho-python/commit/a3b8929f1ea44bc81e9b951fd64561f3b87ee43e))
* **api:** update via SDK Studio ([b4e8264](https://github.com/plastic-labs/honcho-python/commit/b4e8264dc8217501e7156add80d3fd851a765823))
* **api:** update via SDK Studio ([00312fa](https://github.com/plastic-labs/honcho-python/commit/00312fa88bd297f45b34b78a06d7831b9fb8c91a))
* **api:** update via SDK Studio ([c3e1dbf](https://github.com/plastic-labs/honcho-python/commit/c3e1dbf8bb4d08c78ba614d2213f4e5a94ed368a))


### Chores

* go live ([#1](https://github.com/plastic-labs/honcho-python/issues/1)) ([accf7c0](https://github.com/plastic-labs/honcho-python/commit/accf7c008b22880202d49dde642444b95b362331))
